@@ -95,19 +95,19 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_iam
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ProviderBase(
-    aws_cdk.Resource,
+    _aws_cdk_ceddda9d.Resource,
     metaclass=jsii.JSIIAbstractClass,
     jsii_type="@pahud/cdk-github-oidc.ProviderBase",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         account: typing.Optional[builtins.str] = None,
@@ -124,20 +124,10 @@ class ProviderBase(
         :param region: The AWS region this resource belongs to. Default: - the resource is in the same region as the stack it belongs to
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                account: typing.Optional[builtins.str] = None,
-                environment_from_arn: typing.Optional[builtins.str] = None,
-                physical_name: typing.Optional[builtins.str] = None,
-                region: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0bb3773158966ff7fb1ebad575da8fdb2bc7ff2cf5c4774cb2bcec8dfafa52c8)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        props = aws_cdk.ResourceProps(
+        props = _aws_cdk_ceddda9d.ResourceProps(
             account=account,
             environment_from_arn=environment_from_arn,
             physical_name=physical_name,
@@ -150,18 +140,18 @@ class ProviderBase(
     def create_role(
         self,
         id: builtins.str,
-        repo: typing.Sequence[typing.Union["RepositoryConfig", typing.Dict[str, typing.Any]]],
+        repo: typing.Sequence[typing.Union["RepositoryConfig", typing.Dict[builtins.str, typing.Any]]],
         *,
-        assumed_by: aws_cdk.aws_iam.IPrincipal,
+        assumed_by: _aws_cdk_aws_iam_ceddda9d.IPrincipal,
         description: typing.Optional[builtins.str] = None,
         external_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
-        inline_policies: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_iam.PolicyDocument]] = None,
-        managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-        max_session_duration: typing.Optional[aws_cdk.Duration] = None,
+        inline_policies: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_iam_ceddda9d.PolicyDocument]] = None,
+        managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]] = None,
+        max_session_duration: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
         path: typing.Optional[builtins.str] = None,
-        permissions_boundary: typing.Optional[aws_cdk.aws_iam.IManagedPolicy] = None,
+        permissions_boundary: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy] = None,
         role_name: typing.Optional[builtins.str] = None,
-    ) -> aws_cdk.aws_iam.Role:
+    ) -> _aws_cdk_aws_iam_ceddda9d.Role:
         '''
         :param id: -
         :param repo: -
@@ -176,25 +166,10 @@ class ProviderBase(
         :param role_name: A name for the IAM role. For valid values, see the RoleName parameter for the CreateRole action in the IAM API Reference. IMPORTANT: If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name. If you specify a name, you must specify the CAPABILITY_NAMED_IAM value to acknowledge your template's capabilities. For more information, see Acknowledging IAM Resources in AWS CloudFormation Templates. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the role name.
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                repo: typing.Sequence[typing.Union[RepositoryConfig, typing.Dict[str, typing.Any]]],
-                *,
-                assumed_by: aws_cdk.aws_iam.IPrincipal,
-                description: typing.Optional[builtins.str] = None,
-                external_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
-                inline_policies: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_iam.PolicyDocument]] = None,
-                managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-                max_session_duration: typing.Optional[aws_cdk.Duration] = None,
-                path: typing.Optional[builtins.str] = None,
-                permissions_boundary: typing.Optional[aws_cdk.aws_iam.IManagedPolicy] = None,
-                role_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d09d64c19149d51864a55e2496af85be51ff90e4e6779c023429f5f267e1c311)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument repo", value=repo, expected_type=type_hints["repo"])
-        role_props = aws_cdk.aws_iam.RoleProps(
+        role_props = _aws_cdk_aws_iam_ceddda9d.RoleProps(
             assumed_by=assumed_by,
             description=description,
             external_ids=external_ids,
@@ -206,23 +181,27 @@ class ProviderBase(
             role_name=role_name,
         )
 
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.invoke(self, "createRole", [id, repo, role_props]))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.invoke(self, "createRole", [id, repo, role_props]))
 
     @builtins.property
     @jsii.member(jsii_name="openIdConnectProvider")
     @abc.abstractmethod
-    def open_id_connect_provider(self) -> aws_cdk.aws_iam.IOpenIdConnectProvider:
+    def open_id_connect_provider(
+        self,
+    ) -> _aws_cdk_aws_iam_ceddda9d.IOpenIdConnectProvider:
         ...
 
 
 class _ProviderBaseProxy(
     ProviderBase,
-    jsii.proxy_for(aws_cdk.Resource), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_ceddda9d.Resource), # type: ignore[misc]
 ):
     @builtins.property
     @jsii.member(jsii_name="openIdConnectProvider")
-    def open_id_connect_provider(self) -> aws_cdk.aws_iam.IOpenIdConnectProvider:
-        return typing.cast(aws_cdk.aws_iam.IOpenIdConnectProvider, jsii.get(self, "openIdConnectProvider"))
+    def open_id_connect_provider(
+        self,
+    ) -> _aws_cdk_aws_iam_ceddda9d.IOpenIdConnectProvider:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.IOpenIdConnectProvider, jsii.get(self, "openIdConnectProvider"))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
 typing.cast(typing.Any, ProviderBase).__jsii_proxy_class__ = lambda : _ProviderBaseProxy
@@ -248,18 +227,11 @@ class RepositoryConfig:
         :param filter: The sub prefix string from the JWT token used to be validated by AWS. Appended after ``repo:${owner}/${repo}:`` in an IAM role trust relationship. The default value '*' indicates all branches and all tags from this repo. Example: repo:octo-org/octo-repo:ref:refs/heads/demo-branch - only allowed from ``demo-branch`` repo:octo-org/octo-repo:ref:refs/tags/demo-tag - only allowed from ``demo-tag``. repo:octo-org/octo-repo:pull_request - only allowed from the ``pull_request`` event. repo:octo-org/octo-repo:environment:Production - only allowd from ``Production`` environment name. Default: '*'
         '''
         if __debug__:
-            def stub(
-                *,
-                owner: builtins.str,
-                repo: builtins.str,
-                filter: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__49925946471aec49946c0945e0448af69c5c2bf8ed5d208106a8727c6f87fb62)
             check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
             check_type(argname="argument repo", value=repo, expected_type=type_hints["repo"])
             check_type(argname="argument filter", value=filter, expected_type=type_hints["filter"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "owner": owner,
             "repo": repo,
         }
@@ -319,15 +291,13 @@ class Provider(
 ):
     '''The Github OpenID Connect Provider.'''
 
-    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
+    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
         '''
         :param scope: -
         :param id: -
         '''
         if __debug__:
-            def stub(scope: constructs.Construct, id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__30aa2508db9ab16418bf9159b4f1ab34b78924bfd6b4795befda48a0c40497e1)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -336,7 +306,7 @@ class Provider(
     @builtins.classmethod
     def from_account(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
     ) -> ProviderBase:
         '''import the existing provider.
@@ -345,9 +315,7 @@ class Provider(
         :param id: -
         '''
         if __debug__:
-            def stub(scope: constructs.Construct, id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1377ec2421449852e564b1939f566c3d7913ca3c4de49e5f9aac244f45453a04)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(ProviderBase, jsii.sinvoke(cls, "fromAccount", [scope, id]))
@@ -359,8 +327,10 @@ class Provider(
 
     @builtins.property
     @jsii.member(jsii_name="openIdConnectProvider")
-    def open_id_connect_provider(self) -> aws_cdk.aws_iam.IOpenIdConnectProvider:
-        return typing.cast(aws_cdk.aws_iam.IOpenIdConnectProvider, jsii.get(self, "openIdConnectProvider"))
+    def open_id_connect_provider(
+        self,
+    ) -> _aws_cdk_aws_iam_ceddda9d.IOpenIdConnectProvider:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.IOpenIdConnectProvider, jsii.get(self, "openIdConnectProvider"))
 
 
 __all__ = [
@@ -370,3 +340,55 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__0bb3773158966ff7fb1ebad575da8fdb2bc7ff2cf5c4774cb2bcec8dfafa52c8(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    account: typing.Optional[builtins.str] = None,
+    environment_from_arn: typing.Optional[builtins.str] = None,
+    physical_name: typing.Optional[builtins.str] = None,
+    region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d09d64c19149d51864a55e2496af85be51ff90e4e6779c023429f5f267e1c311(
+    id: builtins.str,
+    repo: typing.Sequence[typing.Union[RepositoryConfig, typing.Dict[builtins.str, typing.Any]]],
+    *,
+    assumed_by: _aws_cdk_aws_iam_ceddda9d.IPrincipal,
+    description: typing.Optional[builtins.str] = None,
+    external_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+    inline_policies: typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_iam_ceddda9d.PolicyDocument]] = None,
+    managed_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy]] = None,
+    max_session_duration: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+    path: typing.Optional[builtins.str] = None,
+    permissions_boundary: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IManagedPolicy] = None,
+    role_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__49925946471aec49946c0945e0448af69c5c2bf8ed5d208106a8727c6f87fb62(
+    *,
+    owner: builtins.str,
+    repo: builtins.str,
+    filter: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__30aa2508db9ab16418bf9159b4f1ab34b78924bfd6b4795befda48a0c40497e1(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1377ec2421449852e564b1939f566c3d7913ca3c4de49e5f9aac244f45453a04(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
